@@ -38,6 +38,7 @@ InstanceDeregisteredWaiterName = Literal["instance_deregistered"]
 InstanceInServiceWaiterName = Literal["instance_in_service"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -70,6 +71,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
